@@ -77,8 +77,6 @@ my %default_config = (
     extra_tag_file           => '',
     extra_cluster_file       => '',
     external_cluster_command => '',
-    external_command_mode    => '0600',
-    external_command_pipe    => '',
 
     unmap_on_redraw => "no",    # Debian #329440
 
@@ -87,7 +85,6 @@ my %default_config = (
     history_height => 10,
 
     command             => q{},
-    hide_menu           => 0,
     max_host_menu_items => 30,
 
     macros_enabled   => 'yes',
@@ -101,20 +98,12 @@ my %default_config = (
     menu_send_autotearoff          => 0,
     menu_host_autotearoff          => 0,
 
-    unique_servers    => 0,
     use_all_a_records => 0,
 
     send_menu_xml_file => $ENV{HOME} . '/.clusterssh/send_menu',
 
-    auto_wm_decoration_offsets => "no",    # Debian #842965
-
     # don't set username here as takes precendence over ssh config
     user => '',
-    rows => -1,
-    cols => -1,
-
-    fillscreen => "no",
-
 );
 
 sub new {
@@ -500,7 +489,7 @@ sub dump {
     my ( $self, $no_exit, ) = @_;
 
     $self->debug( 3, 'Dumping config to STDOUT' );
-    print( '# Configuration dump produced by "cssh -d"', $/ );
+    print( '# Configuration dump produced by "cssh -u"', $/ );
 
     foreach my $key ( sort keys %$self ) {
         my $comment = '';
@@ -585,7 +574,7 @@ Duncan Ferguson, C<< <duncan_j_ferguson at yahoo.co.uk> >>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 1999-2016 Duncan Ferguson.
+Copyright 1999-2015 Duncan Ferguson.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
